package
Version:
v1.19.0
Opens a new window with list of versions in this module.
Published: Mar 15, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Bucket interface {
Consume(token uint)
TryConsume(token uint) bool
Destroy()
}
Bucket 令牌桶接口
NewBucket 创建一个令牌桶实例
令牌桶会启动一个单独的 goroutine, 负责生成令牌
每隔 sched 时间, 生成 tokenPerProduce 个 token
maxToken 指定了桶中的最大 token 数
Source Files
¶
Click to show internal directories.
Click to hide internal directories.